summaryrefslogtreecommitdiffstats
path: root/kab
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 03:45:53 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 03:45:53 +0000
commit10308be19ef7fa44699562cc75946e7ea1fdf6b9 (patch)
tree4bc444c00a79e88105f2cfce5b6209994c413ca0 /kab
parent307136d8eef0ba133b78ceee8e901138d4c996a1 (diff)
downloadtdelibs-10308be19ef7fa44699562cc75946e7ea1fdf6b9.tar.gz
tdelibs-10308be19ef7fa44699562cc75946e7ea1fdf6b9.zip
Revert automated changes
Sorry guys, they are just not ready for prime time Work will continue as always git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1212479 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kab')
-rw-r--r--kab/ChangeLog2
-rw-r--r--kab/NEWS2
-rw-r--r--kab/README4
-rw-r--r--kab/README.FORMAT2
-rw-r--r--kab/README.KABAPI4
-rw-r--r--kab/addressbook.cc32
-rw-r--r--kab/addressbook.h32
-rw-r--r--kab/kabapi.cc4
-rw-r--r--kab/kabapi.h2
-rw-r--r--kab/qconfigDB.cc52
-rw-r--r--kab/qconfigDB.h10
-rw-r--r--kab/template.config8
12 files changed, 77 insertions, 77 deletions
diff --git a/kab/ChangeLog b/kab/ChangeLog
index 47a747e93..d3e36fcc1 100644
--- a/kab/ChangeLog
+++ b/kab/ChangeLog
@@ -62,7 +62,7 @@ Tue Dec 22 22:56:58 1998 Mirko Boehm <mirko@kde.org>
1998-10-24 Mirko Boehm <mirko@kde.org>
I debugged the appearance of the EditEntry-dialog. It resizes now
automatically and more accurately.
- The about dialog now tqcontains a KURLLabel that opens an email composer
+ The about dialog now contains a KURLLabel that opens an email composer
when the user clicks on it.
1998-11-02 Mirko Boehm <mirko@kde.org>
diff --git a/kab/NEWS b/kab/NEWS
index fc20a8f3a..e0c13d4a7 100644
--- a/kab/NEWS
+++ b/kab/NEWS
@@ -3,7 +3,7 @@ October 10, 1998:
will be derived from. It is suited with already-connected standard
buttons (OK, Apply, Cancel) and some nice visual features (outer
and inner frame, a common background pixmap for the frames) and
- with ready-to-use tqgeometry management. Hopefully providing cute
+ with ready-to-use geometry management. Hopefully providing cute
dialogs will became easier now.
The new dialogs that use this common base class have a main widget
they manage inside their inner frame. I usually create this widgets
diff --git a/kab/README b/kab/README
index 866f3fb6d..56514215b 100644
--- a/kab/README
+++ b/kab/README
@@ -9,7 +9,7 @@ Cornelius Schumacher, February 2002.
The KDE addressbook
===================
-This directory tqcontains the sources for the kab API provided by "libkab.so".
+This directory contains the sources for the kab API provided by "libkab.so".
kab is the KDE addressbook, users usually know it by one of the applications
using the kab API, kab itselfes. But kab intends to do more, it tries to be
a central database to store personal information for as much KDE
@@ -28,7 +28,7 @@ compile the sources using optimization level 6 (-O6). Stick to -O2, and
it should work. Note: This seems to be solved since gcc 2.95.
Since this directory provides only the kab library, you will have to
-install the kdeutils package, that tqcontains the sources for kab's binary,
+install the kdeutils package, that contains the sources for kab's binary,
also.
Mirko Boehm, March 2000.
diff --git a/kab/README.FORMAT b/kab/README.FORMAT
index ed31133e6..7cce2f402 100644
--- a/kab/README.FORMAT
+++ b/kab/README.FORMAT
@@ -12,7 +12,7 @@ kab handles address book entries. Each entry is meant to represent a
person. Thus, for each entry, it is possible to store more than one
address (like home or business addresses).
-An addressbook database file tqcontains two sections, one to store the
+An addressbook database file contains two sections, one to store the
users entries, called "entries", and one to store the configuration,
called "config". Every subsection of the "entries" section is one
entry, containing
diff --git a/kab/README.KABAPI b/kab/README.KABAPI
index 5c7c1dc4c..278d787d2 100644
--- a/kab/README.KABAPI
+++ b/kab/README.KABAPI
@@ -9,9 +9,9 @@ include directory into your sources.
The documentation of the kab API is contained in the header file
(kabapi.h), you can extract it by parsing the file with kdoc. The kab
-binary source directory in the kdeutils package tqcontains a sample program
+binary source directory in the kdeutils package contains a sample program
that tries to explain some basic functions of the API. It is important
-that you report any bugs you tqfind in the API or in the rest of kab to
+that you report any bugs you find in the API or in the rest of kab to
mirko@kde.org
diff --git a/kab/addressbook.h b/kab/addressbook.h
index 20ebe4379..5057c990c 100644
--- a/kab/addressbook.h
+++ b/kab/addressbook.h
@@ -127,7 +127,7 @@ class CategoriesMap : public TQMap<int, TQString>
* keys). Of course, in different files a key might be used twice. <BR>
* The keys are objects of the type KabKey and define the section in the
* addressbook database where the entry is stored (see QConfigDB
- * reference). Keys tqinvalidate on file changes, so keep track of the
+ * reference). Keys invalidate on file changes, so keep track of the
* signal ::changed. <BR>
* kab watches file changes. If the opened file changes on disk, it is
* automatically reloaded and ::changed() is emitted.
@@ -146,7 +146,7 @@ class CategoriesMap : public TQMap<int, TQString>
* \par The mirror map
* The entries are stored in the QConfigDB object ::data which represents the
* currently opened file. In every file there is a section with the name
- * <TT> entries </TT> that tqcontains a subsection for every entry. The name of
+ * <TT> entries </TT> that contains a subsection for every entry. The name of
* the subsection is the key of the entry. <BR>
* When retrieving the sections, they are ordered alphabetically by their keys.
* This is not what users expect, since the keys show the insertion order of
@@ -157,10 +157,10 @@ class CategoriesMap : public TQMap<int, TQString>
* created as a combination of the entry data, and then displayed in aphabetical
* order in the selector combobox. This map is called the mirror map throughout
* the documentation. It is created or updated every time the database changes.
- * Thus the way to tqfind a special entry is: <OL>
+ * Thus the way to find a special entry is: <OL>
* <LI> the user selects an item in the selector combo box, returning its
* index, </LI>
- * <LI> the index is used to tqfind the key of the entry in the mirror map, </LI>
+ * <LI> the index is used to find the key of the entry in the mirror map, </LI>
* <LI> and finally the entry is retrieved by its key from the database. </LI>
* </OL>
* To modify the sorting order, the way to create the entry descriptors in the
@@ -230,9 +230,9 @@ public:
* First of all, kab II data files (that usually end with \c .kab, while in
* kab 1 the fixed file name was \c addressbook.database) have two main
* sections (see the documentation of the QConfigDB and Section classes),
- * one is called \c config, it tqcontains different file specific
+ * one is called \c config, it contains different file specific
* configuration settings like the last displayed entry, and one section
- * called \c entries that in turn tqcontains a subsection for each entry in
+ * called \c entries that in turn contains a subsection for each entry in
* the database file. The keys of this subsections are the literal strings
* that are used in the KabKey class in the member KabKey::key. Each entry
* subsection has some key-value-pairs described below and another
@@ -260,15 +260,15 @@ public:
* ... (more entries may follow)
* [END] </PRE> <BR>
*
- * \par The fields an entry tqcontains
- * An entry tqcontains all settings that are expected to be unique for all
+ * \par The fields an entry contains
+ * An entry contains all settings that are expected to be unique for all
* addresses directly as key-value-pairs. Everything that is part of a
* specific address of this person is part of an object of the member list
* \c addresses referenced in the next paragraph. <BR>
* The keys defined directly in the entry sections are: <DL>
* <DT>title<DT><DD> The title of that person. </DD>
* <DT>rank<DT><DD>A possible military rank of that person. </DD>
- * <DT>fn<DT><DD>The formatted name. If it is not empty, it tqreplaces the
+ * <DT>fn<DT><DD>The formatted name. If it is not empty, it replaces the
* standard combination of the other name fields in the address
* display. </DD>
* <DT>nameprefix<DT><DD>A possible name prefix. </DD>
@@ -290,7 +290,7 @@ public:
* See the next section for a description of the addresses subsections.
*
* \par The fields of the addresses subsections
- * The section for each entry tqcontains a subsection \c addresses with
+ * The section for each entry contains a subsection \c addresses with
* in turn a subsection for each address. The addresses are enumerated
* in the order they are inserted, their keys are the numbers of
* inserting converted to a string. <BR>
@@ -416,7 +416,7 @@ public:
TQStringList emails; /**< The email addresses. */
TQStringList keywords; /**< The user defined keywords for searching. */
/**
- * Telephon numbers and types. This list tqcontains combinations of telephone
+ * Telephon numbers and types. This list contains combinations of telephone
* numbers and the types of the phones, in this order. See enum
* Telephone above.
*/
@@ -506,7 +506,7 @@ public:
* firstname (add. name) last name,
* if it is true,
+ last name, first name (add. name).
- * If \a initials is true, the text tqcontains initials only:
+ * If \a initials is true, the text contains initials only:
* f. a. name [with reverse==false] or
* name, f. a. [with reverse==true].
* If there is no entry with this key, the method returns ::NoSuchEntry.
@@ -572,7 +572,7 @@ public:
ErrorCode createConfigFile();
ErrorCode loadConfigFile(); /**< Load the local configuration file. */
// ErrorCode configureKab(); /**< Open the configuration dialog for the KabAPI. */
- // TQSize tqsizeHint(); /**< The preferred (minimal) size of the view. */ // ni
+ // TQSize sizeHint(); /**< The preferred (minimal) size of the view. */ // ni
/**
* This method parses a vCard and creates an Entry object from it.
*/
@@ -597,7 +597,7 @@ public:
*/
ErrorCode categories(CategoriesMap& categories);
/**
- * Modify the categories for this addressbook. The map given will tqreplace the
+ * Modify the categories for this addressbook. The map given will replace the
* previoulsy stored one.
*/
ErrorCode setCategories(const CategoriesMap& categories);
@@ -630,12 +630,12 @@ protected:
KabKey nextAvailEntryKey();
/**
* Returns true if both pathes point to the same file.
- * The method resolves relative file names to tqfind this out.
+ * The method resolves relative file names to find this out.
*/
bool isSameFile(const TQString& a, const TQString& b);
/**
* Parse the section and copy its contents into \a entry.
- * The method expects a subsection called \e addresses that tqcontains a
+ * The method expects a subsection called \e addresses that contains a
* number of subsections each containing data for one Entry::Address object.
* All other fields are copied directly into the members of \a entry.
*/
diff --git a/kab/kabapi.cc b/kab/kabapi.cc
index 0910df18b..0cf97905c 100644
--- a/kab/kabapi.cc
+++ b/kab/kabapi.cc
@@ -72,9 +72,9 @@ int KabAPI::exec()
{
listbox->setCurrentItem(0);
}
- listbox->setMinimumSize(listbox->tqsizeHint());
+ listbox->setMinimumSize(listbox->sizeHint());
adjustSize();
- resize(tqminimumSize());
+ resize(minimumSize());
return KDialogBase::exec();
} else {
kdDebug(KAB_KDEBUG_AREA) << "KabAPI::exec: error creating interface."
diff --git a/kab/kabapi.h b/kab/kabapi.h
index cf18800a9..9289d3f98 100644
--- a/kab/kabapi.h
+++ b/kab/kabapi.h
@@ -150,7 +150,7 @@ public:
*/
AddressBook::ErrorCode remove(const KabKey& key);
/**
- * Use getEntryByName to tqfind entries that look like the name given.
+ * Use getEntryByName to find entries that look like the name given.
* The name might be incomplete or diffuse.
* @short This method delivers the closest matches to the given name.
* @param name The name, containing "." for abbreviations.
diff --git a/kab/qconfigDB.h b/kab/qconfigDB.h
index 94359709e..bea329887 100644
--- a/kab/qconfigDB.h
+++ b/kab/qconfigDB.h
@@ -120,9 +120,9 @@ protected:
* complex string where control and non-printable characters get a readable
* representation.
* When retrieving, this strings are translated back by this method.
- * \a orig tqcontains the string read from the file, \a index the position from
+ * \a orig contains the string read from the file, \a index the position from
* where to start the translation (need not be the beginning of the string),
- * \a result tqcontains the transformed string, \a noOfChars the number of
+ * \a result contains the transformed string, \a noOfChars the number of
* characters used to parse the string.
* Returns true if there where no errors while parsing.
* @see makeComplexString
@@ -466,11 +466,11 @@ public:
/**
* Search for the section, returning an iterator to it.
*/
- bool tqfind(const TQCString&, StringSectionMap::iterator&);
+ bool find(const TQCString&, StringSectionMap::iterator&);
/**
* Search for the section, returning a pointer to the section object.
*/
- bool tqfind(const TQCString&, Section*&);
+ bool find(const TQCString&, Section*&);
/**
* Remove this subsection.
*/
@@ -741,7 +741,7 @@ protected:
bool invariant();
/**
* All created lockfiles are notified in this list.
- * The list tqcontains the names of the lockfiles, not of the files itselfes.
+ * The list contains the names of the lockfiles, not of the files itselfes.
*/
static list<TQString> LockFiles;
// ----------------------------------------------------------------------------
diff --git a/kab/template.config b/kab/template.config
index 89bec9254..c925e407e 100644
--- a/kab/template.config
+++ b/kab/template.config
@@ -6,10 +6,10 @@
# a list of supported mail clients:
# MailCommand ... the shell command for starting the mailer
# MailParameters ... the parameters for handing over the mail address
- # <person> will be tqreplaced by a single address
- # <persons> will be tqreplaced by a list of the selected addresses,
+ # <person> will be replaced by a single address
+ # <persons> will be replaced by a list of the selected addresses,
# separated by commas
- # <subject> will be tqreplaced by a possible subject
+ # <subject> will be replaced by a possible subject
[mailer]
[kmail]
MailCommand="kmail"
@@ -19,7 +19,7 @@
# a list of supported talk clients:
# TalkCommand ... the shell command for starting the talk client
# TalkParameters ... the parameters for handing over the talk address
- # <person> will be tqreplaced by a single address
+ # <person> will be replaced by a single address
[talk]
[ktalk]
TalkCommand="ktalk"
diff --git a/kab/addressbook.cc b/kab/addressbook.cc
index d176bf29f..d5813237c 100644
--- a/kab/addressbook.cc
+++ b/kab/addressbook.cc
@@ -225,7 +225,7 @@ bool AddressBook::Entry::Address::nameOfField(const char* key, TQString& value)
for(counter=0; counter<AddressBook::Entry::Address::NoOfFields;
++counter)
{
- pos=fields->tqfind(Fields[counter]);
+ pos=fields->find(Fields[counter]);
if(pos==fields->end())
{
kdDebug(KAB_KDEBUG_AREA) << " UNDEFINED" << endl;
@@ -238,7 +238,7 @@ bool AddressBook::Entry::Address::nameOfField(const char* key, TQString& value)
#endif
}
// ----- now finally do the lookup:
- pos=fields->tqfind(key);
+ pos=fields->find(key);
if(pos==fields->end())
{
return false;
@@ -354,7 +354,7 @@ bool AddressBook::Entry::nameOfField(const char* key, TQString& value)
for(counter=0; counter<AddressBook::Entry::Address::NoOfFields;
++counter)
{
- pos=fields->tqfind(Fields[counter]);
+ pos=fields->find(Fields[counter]);
if(pos==fields->end())
{
kdDebug(KAB_KDEBUG_AREA) << " UNDEFINED" << endl;
@@ -367,7 +367,7 @@ bool AddressBook::Entry::nameOfField(const char* key, TQString& value)
#endif
}
// ----- now finally do the lookup:
- pos=fields->tqfind(key);
+ pos=fields->find(key);
if(pos==fields->end())
{
return false;
@@ -1148,7 +1148,7 @@ AddressBook::change(const KabKey& key, const Entry& entry)
return PermDenied; // cannot get r/w mode
}
// -----
- if(!theEntries->tqfind(key.getKey(), oldEntry))
+ if(!theEntries->find(key.getKey(), oldEntry))
{
rc=NoSuchEntry;
} else {
@@ -1386,13 +1386,13 @@ AddressBook::makeEntryFromSection(Section* section, Entry& entry)
};
const int StringListKeySize=sizeof(StringListKeys)/sizeof(StringListKeys[0]);
// ----- first parse "addresses" subsection:
- if(!section->tqfind(ADDRESS_SUBSECTION, addresses))
+ if(!section->find(ADDRESS_SUBSECTION, addresses))
{
return InternError; // no subsection called "addresses"
}
for(pos=addresses->sectionsBegin(); pos!=addresses->sectionsEnd(); ++pos)
{
- if(!addresses->tqfind((*pos).first, addressSection))
+ if(!addresses->find((*pos).first, addressSection))
{
return InternError; // no section we have an iterator for?
}
@@ -1404,7 +1404,7 @@ AddressBook::makeEntryFromSection(Section* section, Entry& entry)
temp.addresses.push_back(address);
} else {
kdDebug(KAB_KDEBUG_AREA)
- << "AddressBook::makeEntryFromSection: cannot tqfind all fields "
+ << "AddressBook::makeEntryFromSection: cannot find all fields "
<< "in an address subsection." << endl;
}
}
@@ -1505,7 +1505,7 @@ AddressBook::makeSectionFromEntry(const Entry& entry, Section& section)
<< " " << endl;
return InternError;
}
- if(!section.tqfind(ADDRESS_SUBSECTION, addresses))
+ if(!section.find(ADDRESS_SUBSECTION, addresses))
{
kdDebug(KAB_KDEBUG_AREA)
<< "AddressBook::makeSectionFromEntry: cannot get new section." << endl;
@@ -1522,7 +1522,7 @@ AddressBook::makeSectionFromEntry(const Entry& entry, Section& section)
<< "AddressBook::makeSectionFromEntry: cannot create address " << endl;
return InternError;
}
- if(!addresses->tqfind(key, address))
+ if(!addresses->find(key, address))
{
kdDebug(KAB_KDEBUG_AREA)
<< "AddressBook::makeSectionFromEntry: cannot get new " << endl;
@@ -1596,7 +1596,7 @@ AddressBook::createNew(const TQString& filename)
|| !db.setFileName(KabTemplateFile, true, true))
{
KMessageBox::error(this,
- i18n("Cannot tqfind kab's template file.\n"
+ i18n("Cannot find kab's template file.\n"
"You cannot create new files."),
i18n("File Error"));
return InternError;
@@ -1648,7 +1648,7 @@ AddressBook::createConfigFile()
|| !db.setFileName(ConfigTemplateFile, true, true))
{
KMessageBox::error(this,
- i18n("Cannot tqfind kab's configuration template file.\n"
+ i18n("Cannot find kab's configuration template file.\n"
"kab cannot be configured."),
i18n("File Error"));
@@ -1705,7 +1705,7 @@ AddressBook::loadConfigFile()
}
} else {
KMessageBox::information(this,
- i18n("Cannot tqfind kab's local configuration file.\n"
+ i18n("Cannot find kab's local configuration file.\n"
"kab cannot be configured."),
i18n("File Error"));
return NoSuchFile;
@@ -1872,7 +1872,7 @@ AddressBook::ErrorCode AddressBook::Entry::get(const char* fieldname, TQVariant&
field=custom;
return NoError;
}
// ----- we did not tqfind that field:
return NoSuchField;
}
@@ -1939,7 +1939,7 @@ AddressBook::ErrorCode AddressBook::Entry::Address::get(const char* fieldname,
field=state;
return NoError;
}
// ----- we did not tqfind that field:
return NoSuchField;
}
@@ -2005,7 +2005,7 @@ AddressBook::ErrorCode AddressBook::categories(CategoriesMap& cat)
section=categoriesSection();
Q_CHECK_PTR(section);
// -----
- if(!section->tqfind(KAB_CATEGORY_KEY, categories))
+ if(!section->find(KAB_CATEGORY_KEY, categories))
{
kdDebug(KAB_KDEBUG_AREA)
<< "AddressBook::categories: error in database structure."
@@ -1872,7 +1872,7 @@ AddressBook::ErrorCode AddressBook::Entry::get(const char* fieldname, TQVariant&
return NoError;
}
- // ----- we did not tqfind that field:
+ // ----- we did not find that field:
return NoSuchField;
}
@@ -1939,7 +1939,7 @@ AddressBook::ErrorCode AddressBook::Entry::Address::get(const char* fieldname,
return NoError;
}
- // ----- we did not tqfind that field:
+ // ----- we did not find that field:
return NoSuchField;
}
diff --git a/kab/qconfigDB.cc b/kab/qconfigDB.cc
index e7edfc706..a49388ff9 100644
--- a/kab/qconfigDB.cc
+++ b/kab/qconfigDB.cc
@@ -73,7 +73,7 @@ static void tokenize(list<TQCString>& res, const TQCString& text, char tr, bool
while(zwei!=-1)
{
teil="";
- zwei=text.tqfind(tr, eins);
+ zwei=text.find(tr, eins);
if(zwei!=-1)
{
teil=text.mid(eins, zwei-eins);
@@ -472,7 +472,7 @@ KeyValueMap::getRaw(const TQCString& key, TQCString& value) const
// ###########################################################################
kdDebug(GUARD, KAB_KDEBUG_AREA) <<
"KeyValueMap::getRaw: trying to get raw value for key \"" << key << "\" ...\n";
- StringStringMap::iterator pos=data->tqfind(key);
+ StringStringMap::iterator pos=data->find(key);
// -----
if(pos==data->end())
{
@@ -503,7 +503,7 @@ KeyValueMap::insertRaw(const TQCString& key, const TQCString& value, bool force)
kdDebug() << "KeyValueMap::insertRaw: tried to insert empty key." << endl;
return false;
}
- if(force) // entry will be tqreplaced
+ if(force) // entry will be replaced
{
n=data->erase(key);
}
@@ -573,7 +573,7 @@ KeyValueMap::insertLine(TQCString line, bool force, bool relax, bool encode)
return false;
}
// -----
- index=line.tqfind('=');
+ index=line.find('=');
if(index==-1) // not found
{
kdDebug() << "KeyValueMap::insertLine: no \"=\" found in \""<<line<<"\".\n";
@@ -680,7 +680,7 @@ KeyValueMap::get(const TQCString& key, TQString& value) const
<< key << " not in KeyValueMap.\n";
return false;
}
// ----- tqfind its state:
value=TQString::fromUtf8(v); // is there a better way?
kdDebug(GUARD, KAB_KDEBUG_AREA) << "KeyValueMap::get[QString]: success, value"
" (in UTF8) is " << v << endl;
@@ -721,7 +721,7 @@ KeyValueMap::get(const TQCString& key, bool& value) const
<< key << " not in KeyValueMap.";
return false;
}
// ----- tqfind its state:
v=v.stripWhiteSpace();
if(v=="true")
{
@@ -1011,11 +1011,11 @@ KeyValueMap::get(const TQCString& key, list<TQCString>& values) const
}
// -----
for(;;)
- { // ----- parten the string down into a list, tqfind special characters:
+ { // ----- parten the string down into a list, find special characters:
second=first;
for(;;)
{
- second=raw.tqfind('\\', second);
+ second=raw.find('\\', second);
// ----- this may never be the last and also not the second last
// character in a complex string:
if(second!=-1)
@@ -1120,11 +1120,11 @@ KeyValueMap::get(const TQCString& key, TQStrList& values) const
}
// -----
for(;;)
- { // ----- parten the string down into a list, tqfind special characters:
+ { // ----- parten the string down into a list, find special characters:
second=first;
for(;;)
{
- second=raw.tqfind('\\', second);
+ second=raw.find('\\', second);
// ----- this may never be the last and also not the second last
// character in a complex string:
if(second!=-1)
@@ -1471,15 +1471,15 @@ Section::add(const TQCString& name, Section* section)
}
bool
-Section::tqfind(const TQCString& name, StringSectionMap::iterator& result)
+Section::find(const TQCString& name, StringSectionMap::iterator& result)
{
register bool GUARD; GUARD=false;
// ###########################################################################
- kdDebug(GUARD, KAB_KDEBUG_AREA) << "Section::tqfind: trying to get section "
+ kdDebug(GUARD, KAB_KDEBUG_AREA) << "Section::find: trying to get section "
"\""<<name<<"\" ... \n";
StringSectionMap::iterator pos;
// -----
- pos=sections.tqfind(name);
+ pos=sections.find(name);
if(pos==sections.end())
{
kdDebug(GUARD, KAB_KDEBUG_AREA) << "failed, no such section." << endl;
@@ -1498,7 +1498,7 @@ Section::remove(const TQCString& name)
// ###########################################################################
StringSectionMap::iterator pos;
// -----
- if(!tqfind(name, pos))
+ if(!find(name, pos))
{
return false; // no such section
} else {
@@ -1509,12 +1509,12 @@ Section::remove(const TQCString& name)
}
bool
-Section::tqfind(const TQCString& name, Section*& section)
+Section::find(const TQCString& name, Section*& section)
{
// ###########################################################################
StringSectionMap::iterator pos;
// -----
- if(!tqfind(name, pos))
+ if(!find(name, pos))
{
return false;
} else {
@@ -1637,7 +1637,7 @@ Section::readSection(TQTextStream& file, bool finish)
{
name=nameOfSection(line);
add(name);
- tqfind(name, temp);
+ find(name, temp);
if(!temp->readSection(file))
{
kdDebug() << "Section::readSection: unable to read "
@@ -1675,7 +1675,7 @@ Section::isBeginOfSection(TQCString line)
return false;
}
// -----
- if(line.tqcontains("END"))
+ if(line.contains("END"))
{
return false;
} else {
@@ -1708,8 +1708,8 @@ Section::isEndOfSection(TQCString line)
"Section::isBeginOfSection: does not match." << endl;
return false;
}
- // ----- tqfind the word inside the brackets:
- for(first=1; line[first]==' '; ++first); // tqfind first non-whitespace character
+ // ----- find the word inside the brackets:
+ for(first=1; line[first]==' '; ++first); // find first non-whitespace character
for(second=first; line[second]!=' ' && line[second]!=']'; ++second);
temp=line.mid(first, second-first);
if(temp=="END")
@@ -1744,8 +1744,8 @@ Section::nameOfSection(const TQCString& line)
{
return "";
}
- // ----- tqfind the word inside the brackets:
- for(first=1; temp[first]==' '; ++first); // tqfind first non-whitespace character
+ // ----- find the word inside the brackets:
+ for(first=1; temp[first]==' '; ++first); // find first non-whitespace character
for(second=first; temp[second]!=' ' && temp[second]!=']'; ++second);
temp=temp.mid(first, second-first);
if(temp=="END")
@@ -1864,7 +1864,7 @@ QConfigDB::get(const list<TQCString>& key, KeyValueMap*& map)
}
for(pos=key.begin(); pos!=key.end(); ++pos)
{
- if(!section->tqfind(*pos, section))
+ if(!section->find(*pos, section))
{
kdDebug(GUARD, KAB_KDEBUG_AREA) <<
"failed,\n at least the element \""
@@ -1902,7 +1902,7 @@ QConfigDB::createSection(const list<TQCString>& key)
pos=key.begin();
for(index=0; index<key.size()-1; index++)
{
- if(!section->tqfind(*pos, section))
+ if(!section->find(*pos, section))
{ // this section is not declared
Section* temp=new Section; // WORK_TO_DO: memory hole?
if(section->add(*pos, temp))
@@ -1975,7 +1975,7 @@ QConfigDB::stringToKeylist(const TQCString& desc)
}
for(;;)
{
- second=desc.tqfind('/', first);
+ second=desc.find('/', first);
if(second==-1)
{
if((unsigned)first<desc.length()+1)
@@ -2020,7 +2020,7 @@ QConfigDB::get(const list<TQCString>& key, Section*& section)
// -----
for(pos=key.begin(); pos!=key.end(); ++pos)
{
- if(!temp->tqfind(*pos, temp))
+ if(!temp->find(*pos, temp))
{
kdDebug(GUARD, KAB_KDEBUG_AREA) << "failure, no such section.";
return false;
@@ -680,7 +680,7 @@ KeyValueMap::get(const TQCString& key, TQString& value) const
return false;
}
- // ----- tqfind its state:
+ // ----- find its state:
value=TQString::fromUtf8(v); // is there a better way?
kdDebug(GUARD, KAB_KDEBUG_AREA) << "KeyValueMap::get[QString]: success, value"
@@ -721,7 +721,7 @@ KeyValueMap::get(const TQCString& key, bool& value) const
return false;
}
- // ----- tqfind its state:
+ // ----- find its state:
v=v.stripWhiteSpace();
if(v=="true")